summaryrefslogtreecommitdiff
path: root/src/utilcode/ccomprc.cpp
diff options
context:
space:
mode:
authorJan Kotas <jkotas@microsoft.com>2015-05-11 11:49:22 -0700
committerJan Kotas <jkotas@microsoft.com>2015-05-11 18:52:39 -0700
commitade0ad4f58c78a1d7e215c81d996e4ff409ecc2b (patch)
tree41b63bf713f48baa8d45b2b04b771e0d9f6379cf /src/utilcode/ccomprc.cpp
parentb383e3ca6cf3089e4b45edd501b1695c8e84d607 (diff)
downloadcoreclr-ade0ad4f58c78a1d7e215c81d996e4ff409ecc2b.tar.gz
coreclr-ade0ad4f58c78a1d7e215c81d996e4ff409ecc2b.tar.bz2
coreclr-ade0ad4f58c78a1d7e215c81d996e4ff409ecc2b.zip
Update assertion failure message
Diffstat (limited to 'src/utilcode/ccomprc.cpp')
-rw-r--r--src/utilcode/ccomprc.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/utilcode/ccomprc.cpp b/src/utilcode/ccomprc.cpp
index f78640c769..68304daca8 100644
--- a/src/utilcode/ccomprc.cpp
+++ b/src/utilcode/ccomprc.cpp
@@ -837,9 +837,10 @@ HRESULT CCompRC::LoadString(ResourceCategory eCategory, LocaleID langId, UINT iR
if ( hr != E_OUTOFMEMORY)
{
- // Shouldn't be any reason for this condition but the case where we
- // used the wrong ID or didn't update the resource DLL.
- _ASSERTE(0);
+ // Shouldn't be any reason for this condition but the case where
+ // the resource dll is missing, code used the wrong ID or developer didn't
+ // update the resource DLL.
+ _ASSERTE(!"Missing mscorrc.dll or mscorrc.debug.dll?");
hr = HRESULT_FROM_GetLastError();
}
break;